@@ -28,6 +28,7 @@ class GatewayType(IntEnum):
     KIZBOX_MINI_OVP = 43
     HI_BOX = 44  # Hi Kumo AHP-SMB01 Hi Box (constant added manually)
     HATTARA_RAIL_DIN = 47
+    WIZZ_BOX = 52
     CONNEXOON_RTS = 53
     OPENDOORS_LOCK_SYSTEM = 54
     CONNEXOON_RTS_JAPAN = 56
@@ -47,6 +48,7 @@ class GatewayType(IntEnum):
     TAHOMA_SWITCH = 98
     SOMFY_CONNECTIVITY_KIT = 99
     COZYTOUCH_V2 = 105
+    TAHOMA_RAIL_DIN_S = 108
 
     @classmethod
     def _missing_(cls, value):  # type: ignore
